[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [calligra] kexi/widget: SVN_SILENT emmited->emitted (silent)
From:       Jaroslaw Staniek <staniek () kde ! org>
Date:       2011-08-31 23:06:35
Message-ID: 20110831230635.27BA4A60B9 () git ! kde ! org
[Download RAW message or body]

Git commit d52e8fe84a997b47a6ad87aa04548f485084e690 by Jaroslaw Staniek.
Committed on 31/08/2011 at 23:00.
Pushed by staniek into branch 'master'.

SVN_SILENT emmited->emitted

M  +1    -1    kexi/widget/KexiProjectNavigator.h
M  +4    -4    kexi/widget/tableview/kexitableview.h
M  +1    -1    kexi/widget/KexiProjectListView.h

http://commits.kde.org/calligra/d52e8fe84a997b47a6ad87aa04548f485084e690

diff --git a/kexi/widget/KexiProjectListView.h b/kexi/widget/KexiProjectListView.h
index 2e6e020..755579b 100644
--- a/kexi/widget/KexiProjectListView.h
+++ b/kexi/widget/KexiProjectListView.h
@@ -108,7 +108,7 @@ public slots:
 signals:
     void openItem(KexiPart::Item*, Kexi::ViewMode viewMode);
 
-    /*! this signal is emmited when user double clicked (or single -depending on settings)
+    /*! this signal is emitted when user double clicked (or single -depending on settings)
      or pressed return ky on the part item.
      This signal differs from openItem() signal in that if the object is already opened
      in view mode other than \a viewMode, the mode is not changed. */
diff --git a/kexi/widget/KexiProjectNavigator.h b/kexi/widget/KexiProjectNavigator.h
index 7204db9..67b3bc5 100644
--- a/kexi/widget/KexiProjectNavigator.h
+++ b/kexi/widget/KexiProjectNavigator.h
@@ -143,7 +143,7 @@ public slots:
 signals:
     void openItem(KexiPart::Item*, Kexi::ViewMode viewMode);
 
-    /*! this signal is emmited when user double clicked (or single -depending on settings)
+    /*! this signal is emitted when user double clicked (or single -depending on settings)
      or pressed return ky on the part item.
      This signal differs from openItem() signal in that if the object is already opened
      in view mode other than \a viewMode, the mode is not changed. */
diff --git a/kexi/widget/tableview/kexitableview.h b/kexi/widget/tableview/kexitableview.h
index f1fc2ae..473d9d8 100644
--- a/kexi/widget/tableview/kexitableview.h
+++ b/kexi/widget/tableview/kexitableview.h
@@ -417,14 +417,14 @@ signals:
 // void contextMenuRequested(KexiDB::RecordData *,  int row, int col, const QPoint &);
     void sortedColumnChanged(int col);
 
     //! emmited when row editing is started (for updating or inserting)
     void rowEditStarted(int row);
 
     //! emmited when row editing is terminated (for updating or inserting)
     //! no matter if accepted or not
     void rowEditTerminated(int row);
 
-    //! emmited when state of 'save/cancel record changes' actions should be updated.
+    //! emitted when state of 'save/cancel record changes' actions should be updated.
     void updateSaveCancelActions();
     
     //! Emitted in initActions() to force reload actions
@@ -622,7 +622,7 @@ protected:
 
     /*! Shows context menu at \a pos for selected cell
      if menu is configured,
-     else: contextMenuRequested() signal is emmited.
+     else: contextMenuRequested() signal is emitted.
      Method used in contentsMousePressEvent() (for right button)
      and keyPressEvent() for Qt::Key_Menu key.
      If \a pos is QPoint(-1,-1) (the default), menu is positioned below the current cell.
@@ -417,14 +417,14 @@ signals:
     void sortedColumnChanged(int col);
 
-    //! emmited when row editing is started (for updating or inserting)
+    //! emitted when row editing is started (for updating or inserting)
     void rowEditStarted(int row);
 
@@ -417,14 +417,14 @@ signals:
     void rowEditStarted(int row);
 
-    //! emmited when row editing is terminated (for updating or inserting)
+    //! emitted when row editing is terminated (for updating or inserting)
     //! no matter if accepted or not
     void rowEditTerminated(int row);


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic